package com.ruoyi.warehouseBusiness.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.warehouseBusiness.domain.TWarehousebillsCntritemsLogger;
import com.ruoyi.warehouseBusiness.mapper.TWarehousebillsCntritemsLoggerMapper;
import com.ruoyi.warehouseBusiness.service.ITWarehousebillsCntritemsLoggerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 凯和箱明细(修改记录)Service业务层处理
 * 
 * @author ruoyi
 * @date 2021-07-05
 */
@Service
public class TWarehousebillsCntritemsLoggerServiceImpl implements ITWarehousebillsCntritemsLoggerService
{
    @Autowired
    private TWarehousebillsCntritemsLoggerMapper tWarehousebillsCntritemsLoggerMapper;

    /**
     * 查询凯和箱明细(修改记录)
     * 
     * @param fId 凯和箱明细(修改记录)ID
     * @return 凯和箱明细(修改记录)
     */
    @Override
    public TWarehousebillsCntritemsLogger selectTWarehousebillsCntritemsLoggerById(Long fId)
    {
        return tWarehousebillsCntritemsLoggerMapper.selectTWarehousebillsCntritemsLoggerById(fId);
    }

    /**
     * 查询凯和箱明细(修改记录)列表
     * 
     * @param tWarehousebillsCntritemsLogger 凯和箱明细(修改记录)
     * @return 凯和箱明细(修改记录)
     */
    @Override
    public List<TWarehousebillsCntritemsLogger> selectTWarehousebillsCntritemsLoggerList(TWarehousebillsCntritemsLogger tWarehousebillsCntritemsLogger)
    {
        return tWarehousebillsCntritemsLoggerMapper.selectTWarehousebillsCntritemsLoggerList(tWarehousebillsCntritemsLogger);
    }

    /**
     * 新增凯和箱明细(修改记录)
     * 
     * @param tWarehousebillsCntritemsLogger 凯和箱明细(修改记录)
     * @return 结果
     */
    @Override
    public int insertTWarehousebillsCntritemsLogger(TWarehousebillsCntritemsLogger tWarehousebillsCntritemsLogger)
    {
        tWarehousebillsCntritemsLogger.setCreateTime(DateUtils.getNowDate());
        return tWarehousebillsCntritemsLoggerMapper.insertTWarehousebillsCntritemsLogger(tWarehousebillsCntritemsLogger);
    }

    /**
     * 修改凯和箱明细(修改记录)
     * 
     * @param tWarehousebillsCntritemsLogger 凯和箱明细(修改记录)
     * @return 结果
     */
    @Override
    public int updateTWarehousebillsCntritemsLogger(TWarehousebillsCntritemsLogger tWarehousebillsCntritemsLogger)
    {
        tWarehousebillsCntritemsLogger.setUpdateTime(DateUtils.getNowDate());
        return tWarehousebillsCntritemsLoggerMapper.updateTWarehousebillsCntritemsLogger(tWarehousebillsCntritemsLogger);
    }

    /**
     * 批量删除凯和箱明细(修改记录)
     * 
     * @param fIds 需要删除的凯和箱明细(修改记录)ID
     * @return 结果
     */
    @Override
    public int deleteTWarehousebillsCntritemsLoggerByIds(Long[] fIds)
    {
        return tWarehousebillsCntritemsLoggerMapper.deleteTWarehousebillsCntritemsLoggerByIds(fIds);
    }

    /**
     * 删除凯和箱明细(修改记录)信息
     * 
     * @param fId 凯和箱明细(修改记录)ID
     * @return 结果
     */
    @Override
    public int deleteTWarehousebillsCntritemsLoggerById(Long fId)
    {
        return tWarehousebillsCntritemsLoggerMapper.deleteTWarehousebillsCntritemsLoggerById(fId);
    }
}
